#!/bin/bash -e

. ./fusion-sys.cfg

# Check whether we have sufficient privileges
if [ $(id -u) -ne 0 ]; then
    echo "This script needs to be run as root/superuser." >&2
    exit 1
fi

# Was previous step completed?
if [ ! -f installed.repos ]; then
    echo "Repos were not properly prepared - run previous script" >&2
    exit 1
fi

# Are prereqs already installed?
if [ -f installed.prereqs ]; then
    echo "Prereqs already installed - skipping..."
    echo "Note: If you want to update the RPMs installed on this system, run your package manager's update command"
    exit 0
fi

# =======================
# Install Prereqs
# -----------------------

# Run basic yum install for now
unsupported="false"
if [ "$distro" == "RedHatEnterpriseServer" ] || [ "$distro" == "CentOS" ] || [ "$distro" == "OracleServer" ] || [ "$distro" == "CloudLinux" ]; then
	if [ "$dist" == "el6" ]; then
        yum install httpd mysql mysql-server php php-pdo php-devel php-mysql php-mbstring php-ldap zip unzip ntp sysstat -y
        yum install -y "@Japanese Support" "@Chinese Support" "@Korean Support";
	elif [ "$dist" == "el7" ]; then

        # Install MySQL or MariaDB because why not make life difficult
        # - practical reasoning is someone might need to use MySQL and/or mariadb doesn't even
        #   exist on their installation due to reasons...

        # Check if both MySQL and MariaDB are available in yum
        av_mariadb=0
        av_mysql=0

        set +e
        if yum info mysql-community-server &>/dev/null; then
            av_mysql=1
        fi
        if yum info mariadb-server &>/dev/null; then
            av_mariadb=1
        fi
        set -e

        # Default to MariaDB unless it doesn't exist
        mysql_res="1"
        if [ $av_mariadb -eq 0 ]; then
            mysql_res="2"
        fi

        # IF we need to ask which MySQL/MariaDB to use...
        if [ "$INTERACTIVE" != "False" ] && [ $av_mysql -eq 1 ] && [ $av_mariadb -eq 1 ]; then
            cat <<-EOF
----------------------------------------

It looks like MySQL and MariaDB are available on your system. Please pick one:
1 - MariaDB (Default)
2 - MySQL Community

----------------------------------------
EOF
            read -p "Which DB server would you like to use? [1]: " mysql_res
        fi

        # Install the package
        if [ "$mysql_res" == "1" ] || [ "$mysql_res" == "" ]; then
            yum install -y mariadb mariadb-server mariadb-devel
        elif [ "$mysql_res" == "2" ]; then
            yum install -y mysql mysql-community-server mysql-community-devel
        else
            echo "You must select one of the options, or nothing and use the default."
            exit 1;
        fi

		yum install httpd php php-pdo php-devel php-mysql php-mbstring php-ldap zip unzip ntp sysstat -y
    elif [ "$dist" == "el8" ]; then
        yum install -y mariadb mariadb-server mariadb-devel httpd php php-pdo php-devel php-json php-xml php-mysqlnd php-mbstring php-ldap zip unzip chrony sysstat
	else
        unsupported="true"
	fi
elif [ "$dist" == "ubuntu16" ] || [ "$dist" == "ubuntu18" ] || [ "$dist" == "ubuntu20" ]; then
    apt-get update
    DEBIAN_FRONTEND=noninteractive apt-get install apache2 libapache2-mod-php mysql-server php php-mysql php-pdo php-curl php-xml php-dev php-mbstring php-ldap zip unzip ntp sysstat -y
elif [ "$dist" == "debian9" ]; then
    apt-get update
    DEBIAN_FRONTEND=noninteractive apt-get install -y apache2 libapache2-mod-php mysql-server php php-mysql php-dev php-xml php-curl php-ldap zip unzip ntp sysstat uuid-runtime sudo net-tools
elif [ "$dist" == "debian10" ]; then
    apt-get update
    DEBIAN_FRONTEND=noninteractive apt-get install -y apache2 libapache2-mod-php mariadb-server php php-mysql php-dev php-xml php-curl php-ldap zip unzip ntp sysstat uuid-runtime sudo net-tools
else
    unsupported="true"
fi

if [ "$unsupported" = "true" ]; then
    echo "Operating system not supported. Supported OS are CentOS/RHEL 7 or 8, Ubuntu 16.04, 18.04, 20.04 LTS, and Debian 9 or 10."
fi

echo "Prerequisites installed OK"
touch installed.prereqs